#
# spec file for package fastjet-contrib
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define shlib libfastjetcontribfragile
Name:           fastjet-contrib
Version:        1.049
Release:        1.4
Summary:        A library of 3rd-party add-ons to FastJet
License:        GPL-2.0-only
URL:            https://fastjet.hepforge.org/contrib/
Source:         https://fastjet.hepforge.org/contrib/downloads/fjcontrib-%{version}.tar.gz
# PATCH-FIX-UPSTREAM - https://github.com/alisw/fastjet/pull/6
Patch0:         reproducible.patch
BuildRequires:  fastjet-devel
BuildRequires:  gcc-c++

%description
%{name} provides a library of 3rd-party add-ons to FastJet.

%package -n %{shlib}
Summary:        Shared library for fastjet-contrib

%description -n %{shlib}
This package provides the shared library for fastjet-contrib.

%package devel
Summary:        Headers for fastjet-contrib
Requires:       %{shlib} = %{version}

%description devel
This package provides the headers for writing code using fastjet-contrib.

%package devel-static
Summary:        Static libraries and headers for fastjet-contrib
Requires:       %{name}-devel = %{version}

%description devel-static
This package provides the static libraries for fastjet-contrib to link against.

%prep
%setup -q -n fjcontrib-%{version}
%patch0 -p1

%build
# %%configure does not work as a few of the args passed to it isn't recognised by the configure script
./configure --fastjet-config=%{_bindir}/fastjet-config --prefix=%{buildroot}%{_prefix}

%make_build fragile-shared

%install
%make_install
make fragile-shared-install

# Thanks to definciencies in configure script, need to move the libraries to the correct loc manually
mkdir -p %{buildroot}%{_libdir}
%if "%{_lib}" != "lib"
mv %{buildroot}%{_prefix}/lib/* %{buildroot}%{_libdir}/
%endif

%files -n %{shlib}
%{_libdir}/*.so

%files devel-static
%doc AUTHORS ChangeLog README NEWS
%license COPYING
%{_libdir}/*.a

%files devel
%license COPYING
%{_includedir}/fastjet/contrib/

%changelog
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 1.049:
  * updated Nsubjettiness to 2.26
* Wed Oct 12 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to sort the file list (boo#1041090)
* Fri Jan  7 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.048:
  * Inclusion of C++11 check files.
- Changes from version 1.047:
  * Adds RecursiveLundEEGenerator for e+e- studies.
* Fri Aug 27 2021 Dirk Stoecker <opensuse@dstoecker.de>
- update to 1.046 with RecursiveTools updated to v2.0.1
  * added rare divide-by-zero in calculation of mu2
* Mon Dec 21 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.045:
  * First release of Centauro (DIS jet algorithm plugin), v 1.0.0.
- Changes from version 1.044:
  * Update of RecursiveTools to 2.0.0.
- Changes from version 1.043:
  * Updates of ConstituentSubtractor to 1.4.5 and LundPlane to
    1.0.3 to fix c++98 compatibility issues.
- Minor specfile cleanups with spec-cleaner.
* Tue Aug 20 2019 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
